@@ -8,7 +8,7 @@ _template_folder = join(dirname(__file__), 'templates')
 
 def load_config(fname, **kwargs) -> dict:
     if fname is None or not isfile(fname):
-        raise FileNotFoundError("Cannot find configuration file '{}'".format(fname))
+        raise FileNotFoundError(f"Cannot find configuration file '{fname}'")
     code = compile(open(fname, 'rb').read(), fname, 'exec')
     cfg = {
         "__builtins__": __builtins__,
@@ -23,7 +23,11 @@ def load_config(fname, **kwargs) -> dict:
 
 
 def load_profile_config(conf_dir, name, profiles=None, **kwargs) -> dict:
-    pc = load_config(join(conf_dir, name + '.py'), **kwargs)
+    base_file = join(conf_dir, name + '.py')
+    if isfile(base_file):
+        pc = load_config(base_file, **kwargs)
+    else:
+        pc = {}
     if profiles:
         profiles = profiles.split(',')
         for profile in reversed(profiles):
