@@ -1,17 +1,22 @@
 # coding=utf-8
 
-from guniflask.security_config import SecurityConfigurerAdapter, HttpSecurityBuilder
+from werkzeug.local import LocalProxy
+from guniflask.security_config import SecurityConfigurer, HttpSecurityBuilder
 from guniflask.security import JwtManager, SecurityContext
 from guniflask.web import RequestFilter
 from guniflask.oauth2 import BearerTokenExtractor
+from guniflask.config import settings
+
+jwt_manager = LocalProxy(lambda: settings['jwt_manager'])
 
 
-class JwtConfigurer(SecurityConfigurerAdapter):
+class JwtConfigurer(SecurityConfigurer):
     def __init__(self, jwt=None):
         super().__init__()
         self.jwt_filter = None
         if isinstance(jwt, dict):
             jwt_manager = JwtManager(**jwt)
+            settings['jwt_manager'] = jwt_manager
             self.jwt_filter = JwtFilter(jwt_manager)
 
     def configure(self, http: HttpSecurityBuilder):
