@@ -1,10 +1,8 @@
 # coding=utf-8
 
 import os
-from os.path import join, exists
+from os.path import join
 import subprocess
-import time
-from threading import Thread
 import json
 
 from guniflask_cli import __version__
@@ -24,8 +22,7 @@ def init_project(proj_dir):
     }
     with open(join(proj_dir, '.guniflask-init.json'), 'w') as f:
         json.dump(settings, f)
-    res = subprocess.run("cd '{}' && guniflask init".format(proj_dir),
-                         shell=True)
+    res = subprocess.run(f"cd '{proj_dir}' && guniflask init", shell=True)
     assert res.returncode == 0
 
 
